@@ -1,23 +1,19 @@
 package Silki::Formatter::WikiToHTML;
 BEGIN {
-  $Silki::Formatter::WikiToHTML::VERSION = '0.23';
+  $Silki::Formatter::WikiToHTML::VERSION = '0.24';
 }
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-use Encode qw( decode );
 use Markdent::Handler::HTMLFilter;
 use Markdent::Handler::Multiplexer;
 use Markdent::Parser;
 use Silki::Markdent::Dialect::Silki::BlockParser;
 use Silki::Markdent::Dialect::Silki::SpanParser;
-use Silki::Markdent::Handler::ExtractWikiLinks;
-use Silki::Markdent::Handler::HeaderCount;
-use Silki::Markdent::Handler::HTMLStream;
+use Silki::Markdent::Handler::HTMLGenerator;
 use Silki::Types qw( Bool );
-use Text::TOC::HTML;
 
 use Moose;
 use MooseX::StrictConstructor;
@@ -62,7 +58,7 @@ sub captured_events_to_html {
 
     my $generator = sub { $captured->replay_events( $_[0] ) };
 
-    return $self->_generate_and_process_html($generator);
+    return $self->_generate_html($generator);
 }
 
 sub wiki_to_html {
@@ -80,65 +76,25 @@ sub wiki_to_html {
         $parser->parse( markdown => $text );
     };
 
-    return $self->_generate_and_process_html($generator);
-}
-
-sub _generate_and_process_html {
-    my $self = shift;
-
-    my ( $html, $counter ) = $self->_generate_html(@_);
-
-    return $self->_process_html( $html, $counter );
+    return $self->_generate_html($generator);
 }
 
 sub _generate_html {
     my $self      = shift;
     my $generator = shift;
 
-    my $buffer = q{};
-    open my $fh, '>:utf8', \$buffer;
-
-    my $html = Silki::Markdent::Handler::HTMLStream->new(
-        output     => $fh,
-        wiki       => $self->_wiki(),
-        user       => $self->_user(),
-        for_editor => $self->_for_editor(),
+    my $html = Silki::Markdent::Handler::HTMLGenerator->new(
+        wiki              => $self->_wiki(),
+        user              => $self->_user(),
+        page              => $self->_page(),
+        nofollow_external => $self->_wiki()->non_member_can_edit(),
+        include_toc       => $self->_include_toc(),
+        for_editor        => $self->_for_editor(),
     );
 
-    my $final_handler = $html;
-    my $counter;
+    $generator->($html);
 
-    if ( $self->_include_toc() ) {
-        $counter = Silki::Markdent::Handler::HeaderCount->new();
-        $final_handler = Markdent::Handler::Multiplexer->new( handlers => [ $html, $counter ] );
-    }
-
-    $generator->($final_handler);
-
-    return ( $buffer, $counter );
-}
-
-sub _process_html {
-    my $self    = shift;
-    my $html    = shift;
-    my $counter = shift;
-
-    return decode( 'utf-8', $html )
-        unless $counter && $counter->count() > 2;
-
-    $html = decode( 'utf-8', $html );
-
-    my $toc = Text::TOC::HTML->new(
-        filter => sub { $_[0]->tagName() =~ /^h[1-4]$/i } );
-
-    my $fake_file = $self . q{};
-    $toc->add_file( file => $fake_file, content => $html );
-
-    return
-          q{<div id="table-of-contents">} . "\n"
-        . $toc->html_for_toc() . "\n"
-        . '</div>' . "\n"
-        . $toc->html_for_document($fake_file);
+    return $html->final_html_output();
 }
 
 __PACKAGE__->meta()->make_immutable();
@@ -156,7 +112,7 @@ Silki::Formatter::WikiToHTML - Turns wikitext into HTML
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 AUTHOR
 
