@@ -1,6 +1,6 @@
 package Silki::Markdent::Dialect::Silki::SpanParser;
 BEGIN {
-  $Silki::Markdent::Dialect::Silki::SpanParser::VERSION = '0.23';
+  $Silki::Markdent::Dialect::Silki::SpanParser::VERSION = '0.24';
 }
 
 use strict;
@@ -64,7 +64,8 @@ sub _match_wiki_link {
     $p{display_text} = $1
         if defined $1;
 
-    my $event = $self->_make_event( 'Silki::Markdent::Event::WikiLink' => %p );
+    my $event
+        = $self->_make_event( 'Silki::Markdent::Event::WikiLink' => %p );
 
     $self->_markup_event($event);
 
@@ -75,7 +76,6 @@ sub _match_file_link {
     my $self = shift;
     my $text = shift;
 
-
     return unless ${$text} =~ / \G
                                 (?:
                                   \[
@@ -94,7 +94,8 @@ sub _match_file_link {
     my %p = ( link_text => $2 );
     $p{display_text} = $1 if defined $1;
 
-    my $event = $self->_make_event( 'Silki::Markdent::Event::FileLink' => %p );
+    my $event
+        = $self->_make_event( 'Silki::Markdent::Event::FileLink' => %p );
 
     $self->_markup_event($event);
 
@@ -117,7 +118,8 @@ sub _match_image_link {
 
     my %p = ( link_text => $1 );
 
-    my $event = $self->_make_event( 'Silki::Markdent::Event::ImageLink' => %p );
+    my $event
+        = $self->_make_event( 'Silki::Markdent::Event::ImageLink' => %p );
 
     $self->_markup_event($event);
 
@@ -134,8 +136,8 @@ sub _match_plain_text {
     # (possible) end of the plain text. If those things turn out to _not_ be
     # markup, we'll get them on the next pass, because we always match at
     # least one character, so we should never get stuck in a loop.
-    return unless
-        ${$text} =~ /\G
+    return
+        unless ${$text} =~ /\G
                      ( .+? )              # at least one character followed by ...
                      (?=
                        $escape_re
@@ -160,7 +162,7 @@ sub _match_plain_text {
                      )
                     /xgcs;
 
-    $self->_print_debug( "Interpreting as plain text\n\n[$1]\n" )
+    $self->_print_debug("Interpreting as plain text\n\n[$1]\n")
         if $self->debug();
 
     $self->_save_span_text($1);
@@ -183,7 +185,7 @@ Silki::Markdent::Dialect::Silki::SpanParser - Parses span-level markup for the S
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 AUTHOR
 
