@@ -1,6 +1,6 @@
 package Silki::Schema::Page;
 BEGIN {
-  $Silki::Schema::Page::VERSION = '0.23';
+  $Silki::Schema::Page::VERSION = '0.24';
 }
 
 use strict;
@@ -200,29 +200,31 @@ around insert => sub {
 
 sub _BuildPendingPageLinkSelectSQL {
     my $select = Silki::Schema->SQLFactoryClass()->new_select();
-    $select->select(
-        $Schema->table('PendingPageLink')->column('from_page_id') )
-        ->from( $Schema->table('PendingPageLink') )->where(
-        $Schema->table('PendingPageLink')->column('to_wiki_id'),
-        '=', Fey::Placeholder->new()
-        )->and(
-        $Schema->table('PendingPageLink')->column('to_page_title'),
-        '=', Fey::Placeholder->new()
-        );
 
+    #<<<
+    $select
+        ->select( $Schema->table('PendingPageLink')->column('from_page_id') )
+        ->from( $Schema->table('PendingPageLink') )
+        ->where( $Schema->table('PendingPageLink')->column('to_wiki_id'),
+                 '=', Fey::Placeholder->new() )
+        ->and  ( $Schema->table('PendingPageLink')->column('to_page_title'),
+                 '=', Fey::Placeholder->new() );
+    #>>>
     return $select;
 }
 
 sub _BuildPendingPageLinkDeleteSQL {
     my $delete = Silki::Schema->SQLFactoryClass()->new_delete();
-    $delete->delete()->from( $Schema->table('PendingPageLink') )->where(
-        $Schema->table('PendingPageLink')->column('to_wiki_id'),
-        '=', Fey::Placeholder->new()
-        )->and(
-        $Schema->table('PendingPageLink')->column('to_page_title'),
-        '=', Fey::Placeholder->new()
-        );
 
+    #<<<
+    $delete
+        ->delete()
+        ->from( $Schema->table('PendingPageLink') )
+        ->where( $Schema->table('PendingPageLink')->column('to_wiki_id'),
+                 '=', Fey::Placeholder->new() )
+        ->and  ( $Schema->table('PendingPageLink')->column('to_page_title'),
+                 '=', Fey::Placeholder->new() );
+    #>>>
     return $delete;
 }
 
@@ -232,8 +234,8 @@ sub insert_with_content {
 
     my %page_p = (
         map { $_ => delete $p{$_} }
-            grep { exists $p{$_} }
-            map  { $_->name() } $class->Table()->columns()
+        grep { exists $p{$_} }
+        map  { $_->name() } $class->Table()->columns()
     );
 
     my $page;
@@ -360,7 +362,7 @@ sub add_file {
     my $self = shift;
     my ($file) = pos_validated_list( \@_, { isa => 'Silki::Schema::File' } );
 
-    my $last_rev = $self->most_recent_revision();
+    my $last_rev    = $self->most_recent_revision();
     my $new_content = $last_rev->content();
 
     $new_content =~ s/\n*$/\n\n/;
@@ -424,7 +426,7 @@ sub rename {
 }
 
 sub rewritten_content_for_rename {
-    my $self = shift;
+    my $self     = shift;
     my $old_name = shift;
     my $new_name = shift;
 
@@ -455,13 +457,14 @@ sub _BuildPageViewInsert {
 
     my $insert = Silki::Schema->SQLFactoryClass()->new_insert();
 
+    #<<<
     $insert
         ->insert()
         ->into( $page_view_t->columns( 'page_id', 'user_id' ) )
         ->values( page_id => Fey::Placeholder->new(),
                   user_id => Fey::Placeholder->new(),
                 );
-
+    #>>>
     return $insert;
 }
 
@@ -493,11 +496,14 @@ sub _TagsSelect {
 
     my $select = Silki::Schema->SQLFactoryClass()->new_select();
 
+    #<<<
     $select->select( $Schema->table('Tag') )
            ->from( $Schema->tables( 'PageTag', 'Tag' ) )
            ->where( $Schema->table('PageTag')->column('page_id'), '=',
                     Fey::Placeholder->new() )
            ->order_by( $Schema->table('Tag')->column('tag') );
+    #>>>
+    return $select;
 }
 
 sub _MostRecentRevisionSelect {
@@ -505,15 +511,16 @@ sub _MostRecentRevisionSelect {
 
     my $select = Silki::Schema->SQLFactoryClass()->new_select();
 
-    $select->select( $Schema->table('PageRevision') )
-           ->from( $Schema->table('PageRevision') )
-           ->where( $Schema->table('PageRevision')->column('page_id'),
-                    '=', Fey::Placeholder->new()
-                  )
-           ->order_by( $Schema->table('PageRevision')->column('revision_number'),
-                       'DESC' )
-           ->limit(1);
-
+    #<<<
+    $select
+        ->select( $Schema->table('PageRevision') )
+        ->from( $Schema->table('PageRevision') )
+        ->where( $Schema->table('PageRevision')->column('page_id'),
+                 '=', Fey::Placeholder->new() )
+        ->order_by( $Schema->table('PageRevision')->column('revision_number'),
+                    'DESC' )
+        ->limit(1);
+    #>>>
     return $select;
 }
 
@@ -522,15 +529,15 @@ sub _FirstRevisionSelect {
 
     my $select = Silki::Schema->SQLFactoryClass()->new_select();
 
-    $select->select( $Schema->table('PageRevision') )
-           ->from( $Schema->table('PageRevision') )
-           ->where( $Schema->table('PageRevision')->column('page_id'),
-                    '=', Fey::Placeholder->new()
-                  )
-           ->and( $Schema->table('PageRevision')->column('revision_number'),
-                  '=', Fey::Placeholder->new()
-                );
-
+    #<<<
+    $select
+        ->select( $Schema->table('PageRevision') )
+        ->from( $Schema->table('PageRevision') )
+        ->where( $Schema->table('PageRevision')->column('page_id'),
+                 '=', Fey::Placeholder->new() )
+        ->and( $Schema->table('PageRevision')->column('revision_number'),
+               '=', Fey::Placeholder->new() );
+    #>>>
     return $select;
 }
 
@@ -539,13 +546,17 @@ sub _IncomingLinkCountSelect {
 
     my $page_link_t = $Schema->table('PageLink');
 
-    my $count = Fey::Literal::Function->new( 'COUNT',
-        $page_link_t->column('from_page_id') );
-
-    $select->select($count)->from($page_link_t)
-           ->where( $page_link_t->column('to_page_id'), '=',
-                    Fey::Placeholder->new() );
+    my $count = Fey::Literal::Function->new(
+        'COUNT',
+        $page_link_t->column('from_page_id')
+    );
 
+    #<<<
+    $select
+        ->select($count)->from($page_link_t)
+        ->where( $page_link_t->column('to_page_id'), '=',
+                 Fey::Placeholder->new() );
+    #>>>
     return $select;
 }
 
@@ -556,12 +567,15 @@ sub _IncomingLinkSelect {
 
     my ($fk)
         = first { $_->has_column( $page_link_t->column('from_page_id') ) }
+
     $Schema->foreign_keys_between_tables( $page_t, $page_link_t );
 
-    $select->select($page_t)->from( $page_t, $page_link_t, $fk )
-           ->where( $page_link_t->column('to_page_id'), '=',
-                    Fey::Placeholder->new() )->order_by( $page_t->column('title') );
-
+    #<<<
+    $select
+        ->select($page_t)->from( $page_t, $page_link_t, $fk )
+        ->where( $page_link_t->column('to_page_id'), '=',
+                 Fey::Placeholder->new() )->order_by( $page_t->column('title') );
+    #>>>
     return $select;
 }
 
@@ -574,25 +588,27 @@ sub _FileCountSelect {
         $file_t->column('file_id')
     );
 
-    $select->select($count)
-           ->from($file_t)
-           ->where( $file_t->column('page_id'), '=',
-                    Fey::Placeholder->new() );
-
+    #<<<
+    $select
+        ->select($count)
+        ->from($file_t)
+        ->where( $file_t->column('page_id'), '=', Fey::Placeholder->new() );
+    #>>>
     return $select;
 }
 
 sub _FileSelect {
     my $select = Silki::Schema->SQLFactoryClass()->new_select();
 
-    my $file_t = $Schema->table( 'File' );
-
-    $select->select($file_t)
-           ->from( $file_t )
-           ->where( $file_t->column('page_id'), '=',
-                    Fey::Placeholder->new() )
-           ->order_by( $file_t->column('filename') );
+    my $file_t = $Schema->table('File');
 
+    #<<<
+    $select
+        ->select($file_t)
+        ->from( $file_t )
+        ->where( $file_t->column('page_id'), '=', Fey::Placeholder->new() )
+        ->order_by( $file_t->column('filename') );
+    #>>>
     return $select;
 }
 
@@ -601,13 +617,17 @@ sub _RevisionCountSelect {
 
     my $page_revision_t = $Schema->table('PageRevision');
 
-    my $count = Fey::Literal::Function->new( 'COUNT',
-        $page_revision_t->column('page_id') );
-
-    $select->select($count)->from($page_revision_t)
-           ->where( $page_revision_t->column('page_id'), '=',
-                    Fey::Placeholder->new() );
+    my $count = Fey::Literal::Function->new(
+        'COUNT',
+        $page_revision_t->column('page_id')
+    );
 
+    #<<<
+    $select
+        ->select($count)->from($page_revision_t)
+        ->where( $page_revision_t->column('page_id'), '=',
+                 Fey::Placeholder->new() );
+    #>>>
     return $select;
 }
 
@@ -635,11 +655,13 @@ sub _BuildRevisionsSelect {
 
     my $page_revision_t = $Schema->table('PageRevision');
 
-    $select->select($page_revision_t)->from($page_revision_t)
-           ->where( $page_revision_t->column('page_id'), '=',
-                    Fey::Placeholder->new() )
-           ->order_by( $page_revision_t->column('revision_number'), 'DESC' );
-
+    #<<<
+    $select
+        ->select($page_revision_t)->from($page_revision_t)
+        ->where( $page_revision_t->column('page_id'), '=',
+                 Fey::Placeholder->new() )
+        ->order_by( $page_revision_t->column('revision_number'), 'DESC' );
+    #>>>
     return $select;
 }
 
@@ -665,7 +687,7 @@ sub add_tags {
                 tag_id  => $tag->tag_id(),
                 );
 
-            push @tag_ids, $tag->tag_id()
+            push @tag_ids, $tag->tag_id();
         }
         else {
             $tag = Silki::Schema::Tag->insert(%tag_p);
@@ -676,7 +698,7 @@ sub add_tags {
 
     Silki::Schema::PageTag->insert_many(
         map { { page_id => $self->page_id(), tag_id => $_, } } @tag_ids )
-            if @tag_ids;
+        if @tag_ids;
 
     return;
 }
@@ -703,6 +725,40 @@ sub delete_tag {
     return;
 }
 
+sub PagesByWikiAndTitle {
+    my $self   = shift;
+    my $titles = shift;
+
+    my $select = Silki::Schema->SQLFactoryClass()->new_select();
+
+    my $page_t = $Schema->table('Page');
+
+    #<<<
+    $select
+        ->select($page_t)
+        ->from  ($page_t); #>>>
+
+    my @keys = keys %{$titles};
+
+    for my $wiki_id (@keys) {
+        #<<<
+        $select->where( '(' )
+               ->and  ( $page_t->column('wiki_id'), '=', $wiki_id )
+               ->and  ( $page_t->column('title'), 'IN', @{ $titles->{$wiki_id} } )
+               ->and  ( ')' );
+        #>>>
+        $select->and('or')
+            unless $wiki_id == $keys[-1];
+    }
+
+    return Fey::Object::Iterator::FromSelect->new(
+        classes => ['Silki::Schema::Page'],
+        select  => $select,
+        dbh => Silki::Schema->DBIManager()->source_for_sql($select)->dbh(),
+        bind_params => [ $select->bind_params() ],
+    );
+}
+
 __PACKAGE__->meta()->make_immutable();
 
 1;
@@ -718,7 +774,7 @@ Silki::Schema::Page - Represents a page
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 AUTHOR
 
