@@ -1,6 +1,6 @@
 package Silki::Web::Form;
 BEGIN {
-  $Silki::Web::Form::VERSION = '0.23';
+  $Silki::Web::Form::VERSION = '0.24';
 }
 
 use strict;
@@ -161,8 +161,10 @@ sub _fill_form_data {
 
     my $html = $self->_form_html_from_dom();
 
-    my $filled = HTML::FillInForm->fill( \$html, $data,
-        ignore_fields => $self->exclude() );
+    my $filled = HTML::FillInForm->fill(
+        \$html, $data,
+        ignore_fields => $self->exclude()
+    );
 
     my $dom = HTML::DOM->new();
     $dom->write($filled);
@@ -222,7 +224,6 @@ sub _form_html_from_dom {
 
 # This bizarro bit seems to fix some tests. Sigh ...
 {
-
     package
         HTML::DOM::Node;
 
@@ -249,7 +250,7 @@ Silki::Web::Form - Does post-processing on HTML forms
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 AUTHOR
 
